/* -*- linux-c -*- */

/* gtkcomboboxtext.h - GtkComboBoxText widget header
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GTK_COMBO_BOX_TEXT_H__
#define __GTK_COMBO_BOX_TEXT_H__

#include "gtkcombobox.h"

#include <gtk/gtktreestore.h>
#include <gtk/gtktreeview.h>
#include <gtk/gtkcellrenderer.h>
#include <gtk/gtkcellrenderertext.h>
#include <gtk/gtktreeselection.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_COMBO_BOX_TEXT               (gtk_combo_box_text_get_type ( ))
#define GTK_COMBO_BOX_TEXT(object)            (GTK_CHECK_CAST ((object), GTK_TYPE_COMBO_BOX_TEXT, GtkComboBoxText))
#define GTK_COMBO_BOX_TEXT_CLASS(klass)       (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_COMBO_BOX_TEXT))
#define GTK_IS_COMBO_BOX_TEXT(object)         (GTK_CHECK_TYPE ((object), GTK_TYPE_COMBO_BOX_TEXT))
#define GTK_IS_COMBO_BOX_TEXT_CLASS(klass)    (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_COMBO_BOX_TEXT))

typedef struct _GtkComboBoxTextClass      GtkComboBoxTextClass;
typedef struct _GtkComboBoxText           GtkComboBoxText;

struct _GtkComboBoxText
{
	GtkComboBox       cbox;

	gboolean          autocomplete;
	gboolean          keep_history;

	GtkObject        *model;
	GtkObject        *column;
	GtkWidget        *entry;
	GtkWidget        *scrolled_window;
	GtkWidget        *tree_view;
	GtkCellRenderer  *cell;
};

struct _GtkComboBoxTextClass
{
	GtkComboBoxClass    parent_class;
	
	void  (*select)        (GtkComboBoxText   *cboxtext,
				const gchar       *string);
	void  (*autocompleted) (GtkComboBoxText   *cboxtext,
				const gchar       *string);
};

void       gtk_combo_box_text_add_string        (GtkComboBoxText   *cboxtext,
						 const gchar       *string);
void       gtk_combo_box_text_construct         (GtkComboBoxText   *cboxtext);
GSList    *gtk_combo_box_text_get_strings       (GtkComboBoxText   *cboxtext);
GtkType    gtk_combo_box_text_get_type          (void);
GtkWidget *gtk_combo_box_text_new               (void);
void       gtk_combo_box_text_remove_string     (GtkComboBoxText   *cboxtext,
						 const gchar       *string);
void       gtk_combo_box_text_remove_matches    (GtkComboBoxText   *cboxtext,
						 const gchar       *pattern);
void       gtk_combo_box_text_set_autocomplete  (GtkComboBoxText   *cboxtext,
						 gboolean           autocomp);
void       gtk_combo_box_text_set_keep_history  (GtkComboBoxText   *cboxtext,
						 gboolean           keep);
void       gtk_combo_box_text_select            (GtkComboBoxText   *cboxtext,
						 const gchar       *string);
gchar     *gtk_combo_box_text_try_complete      (GtkComboBoxText   *cboxtext);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GTK_COMBO_BOX_TEXT_H__ */
